ORGANISM <- "Pteropus alecto"

ASSEMBLIES <- list(
    ## 65598 sequences.
    list(assembly="ASM32557v1",
         assembly_level="Scaffold",
         date="2013/12/04",
         ## GCA_000325575.1 and GCF_000325575.1 are identical.
         assembly_accession="GCF_000325575.1",
         circ_seqs="MT")
)

