ORGANISM <- "Loxodonta africana"

### List of assemblies by date.
ASSEMBLIES <- list(
    ## 2353 sequences.
    list(assembly="Loxafr3.0",
         assembly_level="Scaffold",
         date="2009/07/15",
         ## GCA_000001905.1 and GCF_000001905.1 are identical.
         assembly_accession="GCF_000001905.1",  # loxAfr3
         circ_seqs="MT"),

    ## 1084 sequences.
    list(assembly="mLoxAfr1.hap1",
         assembly_level="Scaffold",
         date="2023/05/15",
         assembly_accession="GCA_030020305.1",
         circ_seqs=character(0)),

    ## 880 sequences.
    list(assembly="mLoxAfr1.hap2",
         assembly_level="Chromosome",
         date="2023/05/16",
         assembly_accession="GCA_030014295.1",
         circ_seqs="atg000016l_rotated"),

    ## 27963 sequences.
    list(assembly="LAfr_Ele567",
         assembly_level="Scaffold",
         date="2023/05/25",
         assembly_accession="GCA_030077915.1",
         circ_seqs=character(0)),

    ## 27722 sequences.
    list(assembly="LAfr_Ele143",
         assembly_level="Scaffold",
         date="2023/05/25",
         assembly_accession="GCA_030078015.1",
         circ_seqs=character(0)),

    ## 30266 sequences.
    list(assembly="LAfr_Ele241",
         assembly_level="Scaffold",
         date="2023/05/25",
         assembly_accession="GCA_030077925.1",
         circ_seqs=character(0)),

    ## 30199 sequences.
    list(assembly="LAfr_Ele66",
         assembly_level="Scaffold",
         date="2023/05/25",
         assembly_accession="GCA_030078065.1",
         circ_seqs=character(0))
)

