ORGANISM <- "Microtus ochrogaster"

ASSEMBLIES <- list(
    list(assembly="MicOch1.0",
         date="2012/12/07",
         extra_info=c(sex="female"),
         assembly_accession="GCA_000317375.1",
         circ_seqs=character(0))
)

