GENOME <- "apiMel2"
ORGANISM <- "Apis mellifera"
ASSEMBLED_MOLECULES <- paste0("Group", 1:16)
CIRC_SEQS <- character(0)

.order_seqlevels <- function(seqlevels)
{
    ordered_seqlevels <- c(ASSEMBLED_MOLECULES, "GroupUn")
    stopifnot(length(seqlevels) == length(ordered_seqlevels))
    idx <- match(ordered_seqlevels, seqlevels)
    stopifnot(!anyNA(idx))
    idx
}

FETCH_ORDERED_CHROM_SIZES <-
    function(goldenPath.url=getOption("UCSC.goldenPath.url"))
{
    chrom_sizes <- GenomeInfoDb:::fetch_chrom_sizes_from_UCSC(GENOME,
                                              goldenPath.url=goldenPath.url)
    oo <- .order_seqlevels(chrom_sizes[ , "chrom"])
    S4Vectors:::extract_data_frame_rows(chrom_sizes, oo)
}

NCBI_LINKER <- list(
    assembly_accession="GCF_000002195.1",
    special_mappings=setNames(paste0("LG", 1:16), paste0("Group", 1:16)),
    unmapped_seqs=list(`pseudo-scaffold`="GroupUn")
)

