ORGANISM <- "Camponotus floridanus"

### List of assemblies by date.
ASSEMBLIES <- list(
    list(assembly="CamFlo_1.0",
         date="2010/09/17",
         assembly_accession="GCA_000147175.1",
         circ_seqs=character(0)),

    list(assembly="Cflo_v7.5",
         date="2018/06/14",
         extra_info=c(strain="SB8"),
         assembly_accession="GCF_003227725.1",
         circ_seqs=character(0))
)

