ORGANISM <- "Mus musculus"

### List of assemblies by date.
ASSEMBLIES <- list(
    list(assembly="MGSCv36",
         date="2006/05/26",
         assembly_accession="GCF_000001635.15",  # mm8
         circ_seqs=character(0)),

    list(assembly="MGSCv37",
         date="2010/10/21",
         extra_info=c(strain="C57BL/6J"),
         assembly_accession="GCF_000001635.18",  # mm9
         circ_seqs="MT"),

    list(assembly="GRCm38",
         date="2012/01/09",
         extra_info=c(strain="C57BL/6J"),
         assembly_accession="GCF_000001635.20",
         circ_seqs="MT"),

    list(assembly="GRCm38.p1",
         date="2012/08/21",
         extra_info=c(strain="C57BL/6J"),
         assembly_accession="GCF_000001635.21",
         circ_seqs="MT"),

    list(assembly="GRCm38.p2",
         date="2013/03/07",
         extra_info=c(strain="C57BL/6J"),
         assembly_accession="GCF_000001635.22",
         circ_seqs="MT"),

    list(assembly="GRCm38.p3",
         date="2014/03/20",
         extra_info=c(strain="C57BL/6J"),
         assembly_accession="GCF_000001635.23",
         circ_seqs="MT"),

    list(assembly="GRCm38.p4",
         date="2015/03/23",
         extra_info=c(strain="C57BL/6J"),
         assembly_accession="GCF_000001635.24",
         circ_seqs="MT"),

    list(assembly="GRCm38.p5",
         date="2016/06/29",
         extra_info=c(strain="C57BL/6J"),
         assembly_accession="GCF_000001635.25",
         circ_seqs="MT"),

    list(assembly="GRCm38.p6",
         date="2017/09/15",
         extra_info=c(strain="C57BL/6J"),
         assembly_accession="GCF_000001635.26",  # mm10
         circ_seqs="MT"),

    list(assembly="GRCm39",
         date="2020/06/24",
         extra_info=c(strain="C57BL/6J"),
         assembly_accession="GCA_000001635.9",  # mm39
         circ_seqs="MT")
)

