ORGANISM <- "Catharus ustulatus"

### List of assemblies by date.
ASSEMBLIES <- list(
    ## 3601 sequences.
    list(assembly="bCatUst1.alt.v2",
         assembly_level="Scaffold",
         date="2020/11/05",
         extra_info=c(sex="female"),
         assembly_accession="GCA_009819505.2",
         circ_seqs=character(0)),

    ## 161 sequences.
    list(assembly="bCatUst1.pri.v2",
         assembly_level="Chromosome",
         date="2020/12/22",
         extra_info=c(sex="female"),
         assembly_accession="GCA_009819885.2",
         circ_seqs="bCatUst1_MT")
)

