ORGANISM <- "Glycine max"

### List of assemblies by date.
ASSEMBLIES <- list(
    ## 1192 sequences.
    list(assembly="Glycine_max_v2.1",
         assembly_level="Chromosome",
         date="2018/07/24",
         extra_info=c(cultivar="Williams 82"),
         assembly_accession="GCF_000004515.5",
         circ_seqs=c("MT", "Pltd")),

    ## 284 sequences.
    list(assembly="Glycine_max_v4.0",
         assembly_level="Chromosome",
         date="2021/03/10",
         extra_info=c(cultivar="Williams 82"),
         assembly_accession="GCF_000004515.6",
         circ_seqs=c("MT", "Pltd")),

    ## 468 sequences.
    list(assembly="ASM2049715v1",
         assembly_level="Chromosome",
         date="2021/10/14",
         extra_info=c(cultivar="Hwangkeum"),
         assembly_accession="GCA_020497155.1",
         circ_seqs=character(0)),

    ## 95 sequences.
    list(assembly="GmBRS537.a1.v2",
         assembly_level="Chromosome",
         date="2021/10/15",
         extra_info=c(cultivar="EMBRAPA BRS 537"),
         assembly_accession="GCA_012273815.2",
         circ_seqs=character(0))
)

