ORGANISM <- "Madurella mycetomatis"

### List of assemblies first by date then by strain.
ASSEMBLIES <- list(
    list(assembly="ASM127576v1",
         assembly_level="Contig",
         date="2015/08/31",
         extra_info=c(strain="mm55"),
         assembly_accession="GCA_001275765.1",
         circ_seqs=character(0)),

    list(assembly="ASM127576v2",
         assembly_level="Scaffold",
         date="2016/03/09",
         extra_info=c(strain="mm55"),
         assembly_accession="GCA_001275765.2",
         circ_seqs=character(0)),

    list(assembly="ASM985944v1",
         assembly_level="Contig",
         date="2020/01/13",
         extra_info=c(strain="NMM-13"),
         assembly_accession="GCA_009859445.1",
         circ_seqs=character(0)),

    list(assembly="ASM986146v1",
         assembly_level="Contig",
         date="2020/01/13",
         extra_info=c(strain="NMM-15"),
         assembly_accession="GCA_009861465.1",
         circ_seqs=character(0)),

    list(assembly="ASM986156v1",
         assembly_level="Contig",
         date="2020/01/13",
         extra_info=c(strain="NMM-18"),
         assembly_accession="GCA_009861565.1",
         circ_seqs=character(0))
)

