ORGANISM <- "Taeniopygia guttata"

### List of assemblies by date.
ASSEMBLIES <- list(
    list(assembly="Taeniopygia_guttata-3.2.4",
         date="2013/02/08",
         assembly_accession="GCA_000151805.2",  # taeGut2
         circ_seqs="MT")
)

