ORGANISM <- "Xenopus tropicalis"

### List of assemblies by date.
ASSEMBLIES <- list(
    list(assembly="UCB_Xtro_10.0",
         assembly_level="Chromosome",
         date="2019/11/14",
         extra_info=c(strain="Nigerian"),
         assembly_accession="GCF_000004195.4",  # xenTro10
         circ_seqs="MT"),

    list(assembly="ASM1336827v1",
         assembly_level="Chromosome",
         date="2020/06/23",
         extra_info=c(strain="Nigerian"),
         assembly_accession="GCA_013368275.1",
         circ_seqs=character(0))
)

