ORGANISM <- "Brassica napus"

### List of assemblies by date.
ASSEMBLIES <- list(
    list(assembly="Bra_napus_v2.0",
         date="2017/09/15",
         assembly_accession="GCF_000686985.2",
         circ_seqs=c("MT", "Pltd"))
)

