ORGANISM <- "Galleria mellonella"

### List of assemblies by date.
ASSEMBLIES <- list(
    list(assembly="ASM258982v1",
         assembly_level="Contig",
         date="2017/10/18",
         assembly_accession="GCA_002589825.1",
         circ_seqs=character(0)),

    list(assembly="ASM364042v1",
         assembly_level="Scaffold",
         date="2018/10/12",
         extra_info=c(sex="male"),
         assembly_accession="GCF_003640425.1",
         circ_seqs="MT"),

    list(assembly="Honeycombmoth_v1",
         assembly_level="Contig",
         date="2019/03/19",
         assembly_accession="GCA_004355975.1",
         circ_seqs=character(0)),

    list(assembly="ASM364042v2",
         assembly_level="Scaffold",
         date="2019/11/06",
         extra_info=c(sex="male"),
         assembly_accession="GCF_003640425.2",
         circ_seqs="MT")
)

