ORGANISM <- "Strigops habroptila"

### List of assemblies by date.
ASSEMBLIES <- list(
    ## 90 sequences.
    list(assembly="bStrHab1.2.pri",
         assembly_level="Chromosome",
         date="2020/03/04",
         ## GCA_004027225.2 and GCF_004027225.2 are identical.
         assembly_accession="GCF_004027225.2",
         circ_seqs="bStrHab1_MT")
)

