ORGANISM <- "Drosophila melanogaster"

### List of assemblies by date.
ASSEMBLIES <- list(
    ## Length of sequence Un is set to NA in assembly report!
    list(assembly="Release 5",
         date="2007/10/22",
         assembly_accession="GCF_000001215.2",  # dm3
         circ_seqs="MT"),

    list(assembly="Release 6 plus MT",
         date="2014/07/25",
         assembly_accession="GCF_000001215.3",
         circ_seqs="MT"),

    list(assembly="Release 6 plus ISO1 MT",
         date="2014/08/01",
         assembly_accession="GCF_000001215.4",  # dm6
         circ_seqs="mitochondrion_genome")
)

