ORGANISM <- "Petromyzon marinus"

### List of assemblies by date.
ASSEMBLIES <- list(
    ## 25005 sequences.
    list(assembly="Petromyzon_marinus-7.0",
         assembly_level="Scaffold",
         date="2010/10/07",
         assembly_accession="GCA_000148955.1",
         circ_seqs=character(0)),

    ## 12061 sequences.
    list(assembly="Pmar_germline 1.0",
         assembly_level="Scaffold",
         date="2017/12/11",
         assembly_accession="GCA_002833325.1",
         circ_seqs=character(0)),

    ## 4064 sequences.
    list(assembly="kPetMar1.alt",
         assembly_level="Scaffold",
         date="2020/02/24",
         assembly_accession="GCA_010993595.1",
         circ_seqs=character(0)),

    ## 1434 sequences.
    list(assembly="kPetMar1.pri",
         assembly_level="Chromosome",
         date="2020/02/24",
         ## GCA_010993605.1 and GCF_010993605.1 are identical.
         assembly_accession="GCA_010993605.1",
         circ_seqs="MT")
)

