ORGANISM <- "Mustela putorius furo"

### List of assemblies by date.
ASSEMBLIES <- list(
    list(assembly="MusPutFur1.0",
         date="2011/06/02",
         assembly_accession="GCF_000215625.1",  # musFur1
         circ_seqs="MT"),

    list(assembly="MusPutFurMale1.0",
         date="2011/12/21",
         assembly_accession="GCA_000239315.1",
         circ_seqs=character(0))
)

