ORGANISM <- "Eucalyptus grandis"

ASSEMBLIES <- list(
    ## 4951 sequences.
    list(assembly="Egrandis1_0",
         assembly_level="Scaffold",
         date="2014/05/02",
         ## GCA_000612305.1 and GCF_000612305.1 are identical.
         assembly_accession="GCA_000612305.1",
         circ_seqs="Pltd"),

    ## 38 sequences.
    list(assembly="ASM1654582v1",
         assembly_level="Chromosome",
         date="2021/01/06",
         ## GCA_016545825.1 and GCF_016545825.1 are identical.
         assembly_accession="GCF_016545825.1",
         circ_seqs=c("Pltd", "MT"))
)

