GENOME <- "susScr2"
ORGANISM <- "Sus scrofa"
ASSEMBLED_MOLECULES <- paste0("chr", c(1:18, "X", "M"))
CIRC_SEQS <- "chrM"

NCBI_LINKER <- list(
    assembly_accession="GCF_000003025.3",
    unmapped_seqs=list(`assembled-molecule`="chrM")
)

