ORGANISM <- "Fundulus heteroclitus"

### List of assemblies by date.
ASSEMBLIES <- list(
    list(assembly="MU-UCD_Fhet_4.1",
         date="2020/08/13",
         assembly_accession="GCA_011125445.2",
         circ_seqs="MT")
)

