ORGANISM <- "Macaca mulatta"

### List of assemblies by date.
ASSEMBLIES <- list(
    list(assembly="Mmul_051212",
         date="2006/02/27",
         extra_info=c(sex="female"),
         assembly_accession="GCA_000002255.2",  # rheMac2
         circ_seqs="MT"),

    list(assembly="CR_1.0",
         date="2011/10/19",
         extra_info=c(sex="female"),
         assembly_accession="GCA_000230795.1",  # rheMac3
         circ_seqs=character(0)),

    list(assembly="Mmul_8.0",
         date="2015/09/18",
         extra_info=c(sex="female"),
         assembly_accession="GCA_000772875.2",
         circ_seqs=character(0)),

    list(assembly="Mmul_8.0.1",
         date="2015/11/30",
         extra_info=c(sex="female"),
         assembly_accession="GCF_000772875.2",  # rheMac8
         circ_seqs="MT"),

    list(assembly="Mmul_9.0",
         date="2019/02/13",
         extra_info=c(sex="female"),
         assembly_accession="GCA_003339765.2",
         circ_seqs=character(0)),

    list(assembly="Mmul_10",
         date="2019/02/13",
         extra_info=c(sex="female"),
         assembly_accession="GCF_003339765.1",  # rheMac10
         circ_seqs="MT")
)

