ORGANISM <- "Gasterosteus aculeatus"

### List of assemblies by date.
ASSEMBLIES <- list(
    list(assembly="ASM18067v1",
         date="2006/02/01",
         assembly_accession="GCA_000180675.1",  # gasAcu1
         circ_seqs=character(0))
)

