ORGANISM <- "Acyrthosiphon pisum"

### List of assemblies by date.
ASSEMBLIES <- list(
    list(assembly="Acyr_1.0",
         date="2008/04/24",
         assembly_accession="GCA_000142985.1",
         circ_seqs="MT"),

    list(assembly="Acyr_2.0",
         date="2010/06/24",
         assembly_accession="GCA_000142985.2",
         circ_seqs="MT"),

    list(assembly="pea_aphid_22Mar2018_4r6ur",
         date="2019/05/20",
         assembly_accession="GCA_005508785.1",
         circ_seqs="MT")
)

