ORGANISM <- "Hordeum vulgare"

### List of assemblies by date.
ASSEMBLIES <- list(
    list(assembly="MorexV3_clr_mecat_scaffolds",
         date="2021/02/09",
         assembly_accession="GCA_904848275.1",
         circ_seqs=character(0)),

    list(assembly="MorexV3_ont__scaffolds",
         date="2021/02/09",
         assembly_accession="GCA_904848285.1",
         circ_seqs=character(0)),

    list(assembly="MorexV3_css_canu_scaffolds",
         date="2021/02/09",
         assembly_accession="GCA_904848295.1",
         circ_seqs=character(0)),

    list(assembly="MorexV3_css_falcon_scaffolds",
         date="2021/02/09",
         assembly_accession="GCA_904848305.1",
         circ_seqs=character(0)),

    list(assembly="MorexV3_clr_wtdbg2_scaffolds",
         date="2021/02/09",
         assembly_accession="GCA_904848315.1",
         circ_seqs=character(0)),

    list(assembly="MorexV3_illumina_tritex_scaffolds",
         date="2021/02/10",
         assembly_accession="GCA_904848325.1",
         circ_seqs=character(0)),

    list(assembly="MorexV3_hybrid_wengan_scaffolds",
         date="2021/02/10",
         assembly_accession="GCA_904849715.1",
         circ_seqs=character(0)),

    list(assembly="AAC_Synergy_1.0",
         date="2021/03/10",
         extra_info=c(cultivar="AAC Synergy"),
         assembly_accession="GCA_017309745.1",
         circ_seqs=character(0)),

    list(assembly="barley_shape_golden_promise_1.0",
         date="2021/03/19",
         assembly_accession="GCA_905310525.1",
         circ_seqs=character(0)),

    list(assembly="MorexV3_pseudomolecules_assembly",
         date="2021/04/01",
         assembly_accession="GCA_904849725.1",
         circ_seqs=character(0))
)

