ORGANISM <- "Pan paniscus"

### List of assemblies by date.
ASSEMBLIES <- list(
    list(assembly="panpan1",
         date="2012/04/24",
         extra_info=c(sex="female"),
         assembly_accession="GCA_000258655.1",  # panPan1
         circ_seqs="MT"),

    list(assembly="panpan1.1",
         date="2015/08/18",
         extra_info=c(sex="female"),
         assembly_accession="GCF_000258655.2",  # panPan2
         circ_seqs="MT"),

    list(assembly="Mhudiblu_PPA_v0",
         date="2020/05/15",
         extra_info=c(sex="female"),
         assembly_accession="GCF_013052645.1",  # panPan3
         circ_seqs="MT")
)

