ORGANISM <- "Patiria miniata"

### List of assemblies by date.
ASSEMBLIES <- list(
    list(assembly="Pmin_1.0",
         date="2012/08/13",
         assembly_accession="GCA_000285935.1",
         circ_seqs=character(0)),

    list(assembly="Pmin_3.0",
         date="2020/12/01",
         assembly_accession="GCF_015706575.1",
         circ_seqs=character(0))
)

