ORGANISM <- "Danio rerio"

### List of assemblies by date.
ASSEMBLIES <- list(
    list(assembly="Zv7",
         date="2008/02/01",
         extra_info=c(strain="Tuebingen"),
         assembly_accession="GCF_000002035.1",  # danRer5
         circ_seqs=character(0)),

    list(assembly="Zv8",
         date="2009/06/23",
         extra_info=c(strain="Tuebingen"),
         assembly_accession="GCF_000002035.3",
         circ_seqs="MT"),

    list(assembly="Zv9",
         date="2010/07/15",
         extra_info=c(strain="Tuebingen"),
         assembly_accession="GCF_000002035.4",  # danRer7
         circ_seqs="MT"),

    list(assembly="GRCz10",
         date="2014/09/02",
         extra_info=c(strain="Tuebingen"),
         assembly_accession="GCA_000002035.3",  # danRer10
         circ_seqs="MT"),

    list(assembly="GRCz11",
         date="2017/05/09",
         extra_info=c(strain="Tuebingen"),
         assembly_accession="GCA_000002035.4",  # danRer11
         circ_seqs="MT")
)

