ORGANISM <- "Gossypium hirsutum"

### List of assemblies by date.
ASSEMBLIES <- list(
    ## 1027 sequences.
    list(assembly="Gossypium_hirsutum_v2.1",
         assembly_level="Chromosome",
         date="2021/02/25",
         ## GCA_007990345.1 and GCF_007990345.1 are identical.
         assembly_accession="GCF_007990345.1",
         circ_seqs=c("MT", "Pltd"))
)

