ORGANISM <- "Cannabis sativa"

### List of assemblies by date.
ASSEMBLIES <- list(
    ## 2362 sequences.
    list(assembly="ASM341772v2",
         assembly_level="Chromosome",
         date="2018/11/26",
         assembly_accession="GCA_003417725.2",
         circ_seqs=character(0)),

    ## 6653 sequences.
    list(assembly="ASM23057v5",
         assembly_level="Chromosome",
         date="2018/11/30",
         assembly_accession="GCA_000230575.5",
         circ_seqs=character(0)),

    ## 221 sequences.
    list(assembly="cs10",
         assembly_level="Chromosome",
         date="2019/02/14",
         assembly_accession="GCF_900626175.2",
         circ_seqs="MT"),

    ## 483 sequences.
    list(assembly="ASM1303036v1",
         assembly_level="Chromosome",
         date="2020/05/12",
         assembly_accession="GCA_013030365.1",
         circ_seqs=character(0)),

    ## 147 sequences.
    list(assembly="Cannbio-2",
         assembly_level="Chromosome",
         date="2020/12/22",
         assembly_accession="GCA_016165845.1",
         circ_seqs=character(0))
)

