ORGANISM <- "Ambystoma mexicanum"

### List of assemblies by date.
ASSEMBLIES <- list(
    ## 611505 sequences.
    list(assembly="AmbMex13_14.1.0",
         assembly_level="Scaffold",
         date="2015/11/25",
         extra_info=c(strain="laboratory"),
         assembly_accession="GCA_001455525.1",
         circ_seqs=character(0)),

    ## 125724 sequences.
    list(assembly="ASM291563v1",
         assembly_level="Scaffold",
         date="2018/02/05",
         extra_info=c(strain="DD151"),
         assembly_accession="GCA_002915635.1",
         circ_seqs=character(0)),

    ## 98070 sequences.
    list(assembly="ASM291563v2",
         assembly_level="Chromosome",
         date="2018/12/04",
         extra_info=c(strain="DD151"),
         assembly_accession="GCA_002915635.2",
         circ_seqs=character(0)),

    ## 27157 sequences.
    list(assembly="AmbMex60DD",
         assembly_level="Chromosome",
         date="2021/04/01",
         extra_info=c(strain="DD151"),
         assembly_accession="GCA_002915635.3",
         circ_seqs=character(0))
)

