ORGANISM <- "Gorilla gorilla gorilla"

ASSEMBLIES <- list(
    ## 5486 sequences.
    list(assembly="Kamilah_GGO_v0",
         assembly_level="Chromosome",
         date="2019/08/28",
         extra_info=c(breed="western lowland gorilla"),
         assembly_accession="GCF_008122165.1",  # gorGor6
         circ_seqs="MT")
)
