ORGANISM <- "Salmo salar"

### List of assemblies by date.
ASSEMBLIES <- list(
    ## 4011 sequences.
    list(assembly="Ssal_v3.1",
         assembly_level="Chromosome",
         date="2021/04/21",
         ## GCA_905237065.2 and GCF_905237065.1 are identical.
         assembly_accession="GCF_905237065.1",
         circ_seqs=character(0)),

    ## 1149 sequences.
    list(assembly="USDA_NASsal_1.1",
         assembly_level="Chromosome",
         date="2022/01/12",
         assembly_accession="GCA_021399835.1",
         circ_seqs=character(0)),

    ## 2653 sequences.
    list(assembly="Ssal_Brian_v1.0",
         assembly_level="Chromosome",
         date="2022/04/01",
         assembly_accession="GCA_923944775.1",
         circ_seqs=character(0)),

    ## 3596 sequences.
    list(assembly="Ssal_ALTA",
         assembly_level="Chromosome",
         date="2022/05/11",
         assembly_accession="GCA_931346935.2",
         circ_seqs=character(0))
)

