ORGANISM <- "Arabidopsis thaliana"

### List of assemblies by date.
ASSEMBLIES <- list(
    list(assembly="TAIR8",
         assembly_level="Complete Genome",
         date="2008/04/24",
         assembly_accession="GCF_000001735.1",
         circ_seqs=c("MT", "Pltd")),

    list(assembly="TAIR9",
         assembly_level="Chromosome",
         date="2011/05/11",
         extra_info=c(ecotype="Columbia"),
         assembly_accession="GCF_000001735.2",
         circ_seqs=character(0)),

    list(assembly="TAIR10",
         assembly_level="Chromosome",
         date="2011/05/11",
         extra_info=c(ecotype="Columbia"),
         assembly_accession="GCF_000001735.3",
         circ_seqs=c("MT", "Pltd")),

    list(assembly="TAIR10.1",
         assembly_level="Chromosome",
         date="2018/03/15",
         extra_info=c(ecotype="Columbia"),
         assembly_accession="GCF_000001735.4",
         circ_seqs=c("MT", "Pltd"))
)

