ORGANISM <- "Drosophila virilis"

### List of assemblies by date.
ASSEMBLIES <- list(
    list(assembly="dvir_caf1",
         date="2006/07/12",
         extra_info=c(strain="TSC#15010-1051.87"),
         assembly_accession="GCA_000005245.1",  # droVir3
         circ_seqs=character(0))
)

