ORGANISM <- "Xenopus laevis"

### List of assemblies by date.
ASSEMBLIES <- list(

    ## 108033 sequences.
    list(assembly="Xenopus_laevis_v2",
         assembly_level="Chromosome",
         date="2016/08/09",
         extra_info=c(sex="female"),
         assembly_accession="GCA_001663975.1",  # xenLae2
         circ_seqs="MT"),

    ## 55 sequences.
    list(assembly="Xenopus_laevis_v10.1",
         assembly_level="Chromosome",
         date="2021/04/12",
         extra_info=c(sex="female"),
         assembly_accession="GCF_017654675.1",
         circ_seqs="MT")
)

