ORGANISM <- "Cavia porcellus"

### List of assemblies by date.
ASSEMBLIES <- list(
    ## 589 sequences.
    list(assembly="mCavPor4.1",
         assembly_level="Scaffold",
         date="2023/12/07",
         extra_info=c(breed="Dunkin Hartley"),
         ## GCF_034190915.1 and GCA_034190915.1 are identical.
         assembly_accession="GCA_034190915.1",
         circ_seqs="MT")
)

