ORGANISM <- "Chlamydomonas reinhardtii"

ASSEMBLIES <- list(
    list(assembly="Chlamydomonas_reinhardtii_v5.5",
         date="2018/01/26",
         extra_info=c(strain="CC-503 cw92 mt+"),
         assembly_accession="GCA_000002595.3",
         circ_seqs=character(0))
)

