ORGANISM <- "Harpegnathos saltator"

### List of assemblies by date.
ASSEMBLIES <- list(
    list(assembly="HarSal_1.0",
         date="2010/09/17",
         assembly_accession="GCA_000147195.1",
         circ_seqs=character(0)),

    list(assembly="Hsal_v8.5",
         date="2018/06/14",
         assembly_accession="GCF_003227715.1",
         circ_seqs=character(0))
)

