GENOME <- "sacCer2"
ORGANISM <- "Saccharomyces cerevisiae"
ASSEMBLED_MOLECULES <- c(paste0("chr", c(as.character(as.roman(1:16)), "M")),
                         "2micron")
CIRC_SEQS <- c("chrM", "2micron")

